@@ -1,6 +1,6 @@
 package POE::Component::Client::DNS::Recursive;
 {
-  $POE::Component::Client::DNS::Recursive::VERSION = '1.04';
+  $POE::Component::Client::DNS::Recursive::VERSION = '1.06';
 }
 
 #ABSTRACT: A recursive DNS client for POE
@@ -9,7 +9,6 @@ use strict;
 use warnings;
 use Carp;
 use Socket;
-use File::Spec;
 use Net::IP::Minimal qw(:PROC);
 use IO::Socket::INET;
 use POE qw(NFA);
@@ -361,18 +360,12 @@ sub _read_socket {
      warn "$!\n";
      return;
   }
-  my ($in,$err);
-  {
-     local *STDOUT;
-     open STDOUT, '>' . File::Spec->devnull();
-     ($in, $err) = Net::DNS::Packet->new( \$message, 1 );
-  }
-  if ( $err ) {
-     warn "$err\n";
+  my ($in, $len) = Net::DNS::Packet->new( \$message, 0 );
+  if ( $@ ) {
+     warn "$@\n";
      return;
   }
-  my $size = length( $in->data );
-  unless ( $size ) {
+  unless ( $len ) {
      warn "Bad size\n";
      return;
   }
@@ -390,8 +383,8 @@ sub _ns_from_cache {
 
 'Recursive lookup, recursive lookup, recursive lookup ....';
 
-
 __END__
+
 =pod
 
 =head1 NAME
@@ -400,7 +393,7 @@ POE::Component::Client::DNS::Recursive - A recursive DNS client for POE
 
 =head1 VERSION
 
-version 1.04
+version 1.06
 
 =head1 SYNOPSIS
 
@@ -541,4 +534,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
